ActionResult class

Action execution result.

Constructors

ActionResult({required bool success, Map<String, dynamic>? updates, String? error})
const
ActionResult.fail(String error)
factory
ActionResult.ok({Map<String, dynamic>? updates})
factory

Properties

error String?
Error message.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
success bool
Whether action succeeded.
final
updates Map<String, dynamic>?
Context updates.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited