Cluster class

A cluster of similar facts.

Constructors

Cluster({required String id, required List<String> members, required List<double> centroid, required double cohesion, String? label})
const

Properties

centroid List<double>
Cluster centroid.
final
cohesion double
Cluster cohesion (0-1).
final
hashCode int
The hash code for this object.
no setterinherited
id String
Cluster ID.
final
label String?
Cluster label.
final
members List<String>
Member fact IDs.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited