CurationOutput class

Output of curation pipeline.

Constructors

CurationOutput({required int processedCount, required int confirmedCount, required int rejectedCount, required int skippedCount, List<String> confirmedIds = const [], List<String> rejectedIds = const []})
const

Properties

confirmedCount int
Candidates confirmed.
final
confirmedIds List<String>
IDs of confirmed candidates.
final
hashCode int
The hash code for this object.
no setterinherited
processedCount int
Total candidates processed.
final
rejectedCount int
Candidates rejected.
final
rejectedIds List<String>
IDs of rejected candidates.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
skippedCount int
Candidates skipped.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited