EventTrigger class

Event-driven trigger.

Implemented types

Constructors

EventTrigger(String eventType, {String? id, String? filter})

Properties

eventType String
Event type to listen for.
final
filter String?
Filter condition.
final
hashCode int
The hash code for this object.
no setterinherited
id String
Trigger identifier.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type TriggerType
Trigger type.
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited