RetryConfiguration class

Retry configuration.

Constructors

RetryConfiguration({int maxAttempts = 3, Duration delay = const Duration(seconds: 1), double backoff = 2.0})
const

Properties

backoff double
Backoff multiplier.
final
delay Duration
Delay between retries.
final
hashCode int
The hash code for this object.
no setterinherited
maxAttempts int
Maximum attempts.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited