Workflow<TContext extends WorkflowContext> class abstract

Base workflow interface.

Constructors

Workflow()

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
Workflow identifier.
no setter
initialState WorkflowState
Initial state.
no setter
name String
Workflow name.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
states List<WorkflowState>
All workflow states.
no setter
transitions List<WorkflowTransition>
All workflow transitions.
no setter
version String
Workflow version.
no setter

Methods

createContext(Map<String, dynamic> data) → TContext
Create new context for this workflow.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
validate() List<String>
Validate workflow definition.

Operators

operator ==(Object other) bool
The equality operator.
inherited