PipelineConfig class
Pipeline configuration.
Constructors
-
PipelineConfig({int maxConcurrency = 1, Duration? timeout, RetryPolicy? retryPolicy, OnErrorStrategy onError = OnErrorStrategy.fail, bool checkpointEnabled = false, Map<
String, dynamic> extra = const {}}) -
const
-
PipelineConfig.fromJson(Map<
String, dynamic> json) -
factory
Properties
- checkpointEnabled → bool
-
Whether checkpointing is enabled.
final
-
extra
→ Map<
String, dynamic> -
Additional configuration.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxConcurrency → int
-
Maximum concurrent executions.
final
- onError → OnErrorStrategy
-
Error handling strategy.
final
- retryPolicy → RetryPolicy?
-
Retry policy.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timeout → Duration?
-
Pipeline timeout.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited